@@ -33,7 +33,6 @@ import orca.mouse_review as mouse_review
 import orca.orca as orca
 import orca.orca_state as orca_state
 import orca.scripts.default as default
-import orca.speech as speech
 
 from .script_utilities import Utilities
 
@@ -76,7 +75,7 @@ class Script(default.Script):
 
         msg = "GTK: locusOfFocus believed to be typeahead. Presenting change."
         debug.println(debug.LEVEL_INFO, msg, True)
-        self.presentObject(event.any_data)
+        self.presentObject(event.any_data, interrupt=True)
 
     def onCheckedChanged(self, event):
         """Callback for object:state-changed:checked accessibility events."""
@@ -91,22 +90,7 @@ class Script(default.Script):
         if not pyatspi.findAncestor(obj, isListBox):
             return
 
-        self.updateBraille(obj)
-        speech.speak(self.speechGenerator.generateSpeech(obj, alreadyFocused=True))
-
-    def onNameChanged(self, event):
-        """Callback for object:property-change:accessible-name events."""
-
-        role = event.source.getRole()
-        try:
-            focusRole = orca_state.locusOfFocus.getRole()
-        except:
-            focusRole = None
-
-        if role == pyatspi.ROLE_FRAME and focusRole == pyatspi.ROLE_TABLE_CELL:
-            return
-
-        default.Script.onNameChanged(self, event)
+        self.presentObject(obj, alreadyFocused=True, interrupt=True)
 
     def onFocus(self, event):
         """Callback for focus: accessibility events."""
@@ -131,6 +115,12 @@ class Script(default.Script):
            and not event.source.getState().contains(pyatspi.STATE_FOCUSED):
             return
 
+        if "Table" in pyatspi.listInterfaces(event.source):
+            selectedChildren = self.utilities.selectedChildren(event.source)
+            if selectedChildren:
+                orca.setLocusOfFocus(event, selectedChildren[0])
+                return
+
         ancestor = pyatspi.findAncestor(orca_state.locusOfFocus, lambda x: x == event.source)
         if not ancestor:
             orca.setLocusOfFocus(event, event.source)
@@ -176,7 +166,8 @@ class Script(default.Script):
     def onSelectionChanged(self, event):
         """Callback for object:selection-changed accessibility events."""
 
-        if self.utilities.isComboBoxWithToggleDescendant(event.source):
+        if self.utilities.isComboBoxWithToggleDescendant(event.source) \
+            and self.utilities.isOrDescendsFrom(orca_state.locusOfFocus, event.source):
             super().onSelectionChanged(event)
             return
 
@@ -213,7 +204,7 @@ class Script(default.Script):
            or obj.getRole() in [pyatspi.ROLE_ALERT, pyatspi.ROLE_INFO_BAR]:
             if obj.parent and obj.parent.getRole() == pyatspi.ROLE_APPLICATION:
                 return
-            self.presentObject(event.source)
+            self.presentObject(event.source, interrupt=True)
             return
 
         super().onShowingChanged(event)
